@@ -1,4 +1,3 @@
-/* This file is in the public domain */
 #include <iostream>
 #include <fstream>
 #include <string>
@@ -7,6 +6,7 @@
 #include <memory>
 
 #include <botan/botan.h>
+#include <botan/libstate.h>
 #include <botan/rsa.h>
 #include <botan/dsa.h>
 #include <botan/dh.h>
@@ -35,8 +35,13 @@
 #include <botan/rng.h>
 using namespace Botan;
 
-SecureVector<byte> decode_hex(const std::string&);
-BigInt to_bigint(const std::string&);
+#include "common.h"
+
+static BigInt to_bigint(const std::string& h)
+   {
+   return BigInt::decode((const byte*)h.data(),
+                         h.length(), BigInt::Hexadecimal);
+   }
 
 #define DEBUG 0
 
@@ -71,10 +76,6 @@ class Fixed_Output_RNG : public RandomNumberGenerator
       u32bit position;
    };
 
-std::vector<std::string> parse(const std::string&);
-void strip_comments(std::string&);
-void strip_newlines(std::string&);
-
 void do_pk_keygen_tests();
 extern void do_x509_tests();
 
@@ -157,11 +158,8 @@ u32bit do_pk_validation_tests(const std::string& filename)
          continue;
          }
 
-      if(alg_count % 4 != 3)
-         {
-         std::cout << '.';
-         std::cout.flush();
-         }
+      std::cout << '.';
+      std::cout.flush();
 
       std::vector<std::string> substr = parse(line);
 
@@ -213,8 +211,9 @@ u32bit do_pk_validation_tests(const std::string& filename)
 
    std::cout << std::endl;
 
-   Init::set_global_rngs(new ANSI_X931_RNG, new ANSI_X931_RNG);
-   Global_RNG::seed();
+   global_state().set_prng(new ANSI_X931_RNG);
+   for(u32bit j = 0; j != 2; j++)
+      Global_RNG::seed(true, 384);
 
    do_pk_keygen_tests();
    do_x509_tests();
@@ -254,8 +253,8 @@ void validate_encryption(PK_Encryptor* e, PK_Decryptor* d,
                          bool& failure)
    {
    SecureVector<byte> message = decode_hex(input);
-   Init::set_global_rngs(new Fixed_Output_RNG(decode_hex(random)),
-                         new Fixed_Output_RNG(decode_hex(random)));
+
+   global_state().set_prng(new Fixed_Output_RNG(decode_hex(random)));
 
    SecureVector<byte> expected = decode_hex(exp);
 
@@ -267,8 +266,9 @@ void validate_encryption(PK_Encryptor* e, PK_Decryptor* d,
       failure = true;
       }
 
-   Init::set_global_rngs(new ANSI_X931_RNG, new ANSI_X931_RNG);
-   Global_RNG::seed();
+   global_state().set_prng(new ANSI_X931_RNG);
+   for(u32bit j = 0; j != 2; j++)
+      Global_RNG::seed(true, 384);
 
    validate_decryption(d, algo, out, message, failure);
    delete e;
@@ -279,8 +279,7 @@ void validate_signature(PK_Verifier* v, PK_Signer* s, const std::string& algo,
                         const std::string& exp, bool& failure)
    {
    SecureVector<byte> message = decode_hex(input);
-   Init::set_global_rngs(new Fixed_Output_RNG(decode_hex(random)),
-                         new Fixed_Output_RNG(decode_hex(random)));
+   global_state().set_prng(new Fixed_Output_RNG(decode_hex(random)));
 
    SecureVector<byte> expected = decode_hex(exp);
 
@@ -308,8 +307,9 @@ void validate_signature(PK_Verifier* v, PK_Signer* s, const std::string& algo,
       failure = true;
       }
 
-   Init::set_global_rngs(new ANSI_X931_RNG, new ANSI_X931_RNG);
-   Global_RNG::seed();
+   global_state().set_prng(new ANSI_X931_RNG);
+   for(u32bit j = 0; j != 2; j++)
+      Global_RNG::seed(true, 384);
 
    delete v;
    delete s;
@@ -346,7 +346,7 @@ u32bit validate_rsa_enc_pkcs8(const std::string& algo,
                                 decoding method we use */
 
    DataSource_Memory keysource((const byte*)str[0].c_str(), str[0].length());
-   PKCS8_PrivateKey* privkey = PKCS8::load_key(keysource, pass);
+   Private_Key* privkey = PKCS8::load_key(keysource, pass);
 
    RSA_PrivateKey* rsapriv = dynamic_cast<RSA_PrivateKey*>(privkey);
    if(!rsapriv)
@@ -466,7 +466,7 @@ u32bit validate_rsa_ver_x509(const std::string& algo,
 
    DataSource_Memory keysource((const byte*)str[0].c_str(), str[0].length());
 
-   X509_PublicKey* key = X509::load_key(keysource);
+   Public_Key* key = X509::load_key(keysource);
 
    RSA_PublicKey* rsakey = dynamic_cast<RSA_PublicKey*>(key);
 
@@ -550,7 +550,7 @@ u32bit validate_dsa_sig(const std::string& algo,
                                 decoding method we use */
 
    DataSource_Memory keysource((const byte*)str[0].c_str(), str[0].length());
-   PKCS8_PrivateKey* privkey = PKCS8::load_key(keysource, pass);
+   Private_Key* privkey = PKCS8::load_key(keysource, pass);
 
    DSA_PrivateKey* dsapriv = dynamic_cast<DSA_PrivateKey*>(privkey);
    if(!dsapriv)
@@ -577,7 +577,7 @@ u32bit validate_dsa_ver(const std::string& algo,
       throw Exception("Invalid input from pk_valid.dat");
 
    DataSource_Memory keysource((const byte*)str[0].c_str(), str[0].length());
-   X509_PublicKey* key = X509::load_key(keysource);
+   Public_Key* key = X509::load_key(keysource);
 
    DSA_PublicKey* dsakey = dynamic_cast<DSA_PublicKey*>(key);
 
@@ -698,21 +698,21 @@ void do_pk_keygen_tests()
 
 #define DL_SIG_KEY(TYPE, GROUP)    \
    {                               \
-   TYPE key(get_dl_group(GROUP));  \
+   TYPE key(DL_Group(GROUP));  \
    key.check_key(true);            \
    std::cout << '.' << std::flush; \
    }
 
 #define DL_ENC_KEY(TYPE, GROUP)    \
    {                               \
-   TYPE key(get_dl_group(GROUP));  \
+   TYPE key(DL_Group(GROUP));  \
    key.check_key(true);            \
    std::cout << '.' << std::flush; \
    }
 
 #define DL_KEY(TYPE, GROUP)        \
    {                               \
-   TYPE key(get_dl_group(GROUP));  \
+   TYPE key(DL_Group(GROUP));  \
    key.check_key(true);            \
    std::cout << '.' << std::flush; \
    }
@@ -722,24 +722,24 @@ void do_pk_keygen_tests()
    IF_SIG_KEY(RW_PrivateKey, 512);
 #endif
 
-   DL_SIG_KEY(DSA_PrivateKey, "DSA-512");
-   DL_SIG_KEY(DSA_PrivateKey, "DSA-768");
-   DL_SIG_KEY(DSA_PrivateKey, "DSA-1024");
+   DL_SIG_KEY(DSA_PrivateKey, "dsa/jce/512");
+   DL_SIG_KEY(DSA_PrivateKey, "dsa/jce/768");
+   DL_SIG_KEY(DSA_PrivateKey, "dsa/jce/1024");
 
-   DL_KEY(DH_PrivateKey, "IETF-768");
-   DL_KEY(DH_PrivateKey, "IETF-2048");
-   DL_KEY(DH_PrivateKey, "DSA-1024");
+   DL_KEY(DH_PrivateKey, "modp/ietf/768");
+   DL_KEY(DH_PrivateKey, "modp/ietf/2048");
+   DL_KEY(DH_PrivateKey, "dsa/jce/1024");
 
 #if !defined(BOTAN_NO_NR)
-   DL_SIG_KEY(NR_PrivateKey, "DSA-512");
-   DL_SIG_KEY(NR_PrivateKey, "DSA-768");
-   DL_SIG_KEY(NR_PrivateKey, "DSA-1024");
+   DL_SIG_KEY(NR_PrivateKey, "dsa/jce/512");
+   DL_SIG_KEY(NR_PrivateKey, "dsa/jce/768");
+   DL_SIG_KEY(NR_PrivateKey, "dsa/jce/1024");
 #endif
 
 #if !defined(BOTAN_NO_ELG)
-   DL_ENC_KEY(ElGamal_PrivateKey, "IETF-768");
-   DL_ENC_KEY(ElGamal_PrivateKey, "IETF-1024");
-   DL_ENC_KEY(ElGamal_PrivateKey, "DSA-1024");
+   DL_ENC_KEY(ElGamal_PrivateKey, "modp/ietf/768");
+   DL_ENC_KEY(ElGamal_PrivateKey, "modp/ietf/1024");
+   DL_ENC_KEY(ElGamal_PrivateKey, "dsa/jce/1024");
 #endif
 
    std::cout << std::endl;
