@@ -1,6 +1,6 @@
 /*************************************************
 * Memory Mapping Allocator Header File           *
-* (C) 1999-2005 The Botan Project                *
+* (C) 1999-2006 The Botan Project                *
 *************************************************/
 
 #ifndef BOTAN_EXT_MMAP_ALLOCATOR_H__
@@ -15,9 +15,12 @@ namespace Botan {
 *************************************************/
 class MemoryMapping_Allocator : public Pooling_Allocator
    {
+   public:
+      MemoryMapping_Allocator() : Pooling_Allocator(64*1024, false) {}
+      std::string type() const { return "mmap"; }
    private:
-      void* alloc_block(u32bit) const;
-      void dealloc_block(void*, u32bit) const;
+      void* alloc_block(u32bit);
+      void dealloc_block(void*, u32bit);
    };
 
 }
