@@ -1,10 +1,10 @@
 /*************************************************
-* GMP Wrapper Header File                        *
-* (C) 1999-2005 The Botan Project                *
+* GMP MPZ Wrapper Header File                    *
+* (C) 1999-2006 The Botan Project                *
 *************************************************/
 
-#ifndef BOTAN_EXT_GNU_MP_WRAP_H__
-#define BOTAN_EXT_GNU_MP_WRAP_H__
+#ifndef BOTAN_EXT_GMP_MPZ_WRAP_H__
+#define BOTAN_EXT_GMP_MPZ_WRAP_H__
 
 #include <botan/bigint.h>
 #include <gmp.h>
@@ -14,7 +14,7 @@ namespace Botan {
 /*************************************************
 * Lightweight GMP mpz_t Wrapper                  *
 *************************************************/
-class GNU_MPZ
+class GMP_MPZ
    {
    public:
       mpz_t value;
@@ -23,12 +23,12 @@ class GNU_MPZ
       void encode(byte[], u32bit) const;
       u32bit bytes() const;
 
-      GNU_MPZ& operator=(const GNU_MPZ&);
+      GMP_MPZ& operator=(const GMP_MPZ&);
 
-      GNU_MPZ(const GNU_MPZ&);
-      GNU_MPZ(const BigInt& = 0);
-      GNU_MPZ(const byte[], u32bit);
-      ~GNU_MPZ();
+      GMP_MPZ(const GMP_MPZ&);
+      GMP_MPZ(const BigInt& = 0);
+      GMP_MPZ(const byte[], u32bit);
+      ~GMP_MPZ();
    };
 
 }
