@@ -1,6 +1,6 @@
 /*************************************************
 * Unix Command Execution Header File             *
-* (C) 1999-2005 The Botan Project                *
+* (C) 1999-2006 The Botan Project                *
 *************************************************/
 
 #ifndef BOTAN_EXT_UNIX_CMD_H__
@@ -18,7 +18,7 @@ namespace Botan {
 *************************************************/
 struct Unix_Program
    {
-   Unix_Program(const std::string& n, u32bit p)
+   Unix_Program(const char* n, u32bit p)
       { name_and_args = n; priority = p; working = true; }
 
    std::string name_and_args;
@@ -26,8 +26,6 @@ struct Unix_Program
    bool working;
    };
 
-extern const Unix_Program DEFAULT_SOURCES[];
-
 /*************************************************
 * Command Output DataSource                      *
 *************************************************/
@@ -48,6 +46,7 @@ class DataSource_Command : public DataSource
       void shutdown_pipe();
 
       const u32bit MAX_BLOCK_USECS, KILL_WAIT;
+
       std::vector<std::string> arg_list;
       struct pipe_wrapper* pipe;
    };
