@@ -1,6 +1,6 @@
 /*************************************************
 * Serpent Source File                            *
-* (C) 1999-2005 The Botan Project                *
+* (C) 1999-2006 The Botan Project                *
 *************************************************/
 
 #include <botan/serpent.h>
@@ -231,12 +231,11 @@ inline void i_transform(u32bit& B0, u32bit& B1, u32bit& B2, u32bit& B3)
 /*************************************************
 * XOR a key block with a data block              *
 *************************************************/
-inline void Serpent::key_xor(u32bit round, u32bit& B0, u32bit& B1,
-                                           u32bit& B2, u32bit& B3) const
-   {
-   B0 ^= round_key[4*round  ]; B1 ^= round_key[4*round+1];
-   B2 ^= round_key[4*round+2]; B3 ^= round_key[4*round+3];
-   }
+#define key_xor(round, B0, B1, B2, B3) \
+   B0 ^= round_key[4*round  ]; \
+   B1 ^= round_key[4*round+1]; \
+   B2 ^= round_key[4*round+2]; \
+   B3 ^= round_key[4*round+3];
 
 /*************************************************
 * Serpent Encryption                             *
@@ -348,10 +347,10 @@ void Serpent::key(const byte key[], u32bit length)
    const u32bit PHI = 0x9E3779B9;
 
    SecureBuffer<u32bit, 140> W;
-   for(u32bit j = 0; j != length / 4; j++)
+   for(u32bit j = 0; j != length / 4; ++j)
       W[j] = make_u32bit(key[4*j+3], key[4*j+2], key[4*j+1], key[4*j]);
    W[length / 4] |= u32bit(1) << ((length%4)*8);
-   for(u32bit j = 8; j != 140; j++)
+   for(u32bit j = 8; j != 140; ++j)
       W[j] = rotate_left(W[j-8] ^ W[j-5] ^ W[j-3] ^ W[j-1] ^ PHI ^ (j-8), 11);
    SBoxE4(W[  8],W[  9],W[ 10],W[ 11]); SBoxE3(W[ 12],W[ 13],W[ 14],W[ 15]);
    SBoxE2(W[ 16],W[ 17],W[ 18],W[ 19]); SBoxE1(W[ 20],W[ 21],W[ 22],W[ 23]);
